@@ -6,11 +6,13 @@ import time
 from prawcore import Redirect
 
 from ...const import API_PATH, urljoin
+from ...exceptions import APIException
 from ..util import permissions_string, stream_generator
 from ..listing.generator import ListingGenerator
 from ..listing.mixins import SubredditListingMixin
 from .base import RedditBase
 from .mixins import MessageableMixin
+from .modmail import ModmailConversation
 from .wikipage import WikiPage
 
 
@@ -48,6 +50,8 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
     """
 
+    # pylint: disable=too-many-public-methods
+
     STR_FIELD = 'display_name'
     MESSAGE_PREFIX = '#'
 
@@ -115,13 +119,20 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
     @property
     def banned(self):
-        """An instance of :class:`.SubredditRelationship`.
+        """Provide an instance of :class:`.SubredditRelationship`.
 
         For example to ban a user try:
 
         .. code-block:: python
 
-           reddit.subreddit('SUBREDDIT').banned.add('NAME', reason='a reason')
+           reddit.subreddit('SUBREDDIT').banned.add('NAME', ban_reason='...')
+
+        To list the banned users along with any notes, try:
+
+        .. code-block:: python
+
+           for ban in reddit.subreddit('SUBREDDIT').banned():
+               print('{}: {}'.format(ban, ban.note))
 
         """
         if self._banned is None:
@@ -130,21 +141,21 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
     @property
     def contributor(self):
-        """An instance of :class:`.ContributorRelationship`."""
+        """Provide an instance of :class:`.ContributorRelationship`."""
         if self._contributor is None:
             self._contributor = ContributorRelationship(self, 'contributor')
         return self._contributor
 
     @property
     def filters(self):
-        """An instance of :class:`.SubredditFilters`."""
+        """Provide an instance of :class:`.SubredditFilters`."""
         if self._filters is None:
             self._filters = SubredditFilters(self)
         return self._filters
 
     @property
     def flair(self):
-        """An instance of :class:`.SubredditFlair`.
+        """Provide an instance of :class:`.SubredditFlair`.
 
         Provides the interface for interacting with a subreddit's flair. For
         example to list all the flair for a subreddit which you have the
@@ -162,28 +173,50 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
     @property
     def mod(self):
-        """An instance of :class:`.SubredditModeration`."""
+        """Provide an instance of :class:`.SubredditModeration`."""
         if self._mod is None:
             self._mod = SubredditModeration(self)
         return self._mod
 
     @property
     def moderator(self):
-        """An instance of :class:`.ModeratorRelationship`."""
+        """Provide an instance of :class:`.ModeratorRelationship`.
+
+        For example to add a moderator try:
+
+        .. code-block:: python
+
+           reddit.subreddit('SUBREDDIT').moderator.add('NAME')
+
+        To list the moderators along with their permissions try:
+
+        .. code-block:: python
+
+           for moderator in reddit.subreddit('SUBREDDIT').moderator():
+               print('{}: {}'.format(moderator, moderator.mod_permissions))
+
+        """
         if self._moderator is None:
             self._moderator = ModeratorRelationship(self, 'moderator')
         return self._moderator
 
+    @property
+    def modmail(self):
+        """Provide an instance of :class:`.Modmail`."""
+        if self._modmail is None:
+            self._modmail = Modmail(self)
+        return self._modmail
+
     @property
     def muted(self):
-        """An instance of :class:`.SubredditRelationship`."""
+        """Provide an instance of :class:`.SubredditRelationship`."""
         if self._muted is None:
             self._muted = SubredditRelationship(self, 'muted')
         return self._muted
 
     @property
     def quaran(self):
-        """An instance of :class:`.SubredditQuarantine`.
+        """Provide an instance of :class:`.SubredditQuarantine`.
 
         This property is named ``quaran`` because ``quarantine`` is a
         Subreddit attribute returned by Reddit to indicate whether or not a
@@ -196,7 +229,7 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
     @property
     def stream(self):
-        """An instance of :class:`.SubredditStream`.
+        """Provide an instance of :class:`.SubredditStream`.
 
         Streams can be used to indefinitely retrieve new comments made to a
         subreddit, like:
@@ -222,14 +255,14 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
     @property
     def stylesheet(self):
-        """An instance of :class:`.SubredditStylesheet`."""
+        """Provide an instance of :class:`.SubredditStylesheet`."""
         if self._stylesheet is None:
             self._stylesheet = SubredditStylesheet(self)
         return self._stylesheet
 
     @property
     def wiki(self):
-        """An instance of :class:`.SubredditWiki`.
+        """Provide an instance of :class:`.SubredditWiki`.
 
         This attribute can be used to discover all wikipages for a subreddit:
 
@@ -256,7 +289,7 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
         :param reddit: An instance of :class:`~.Reddit`.
         :param display_name: The name of the subreddit.
 
-        .. note:: This class should not be initialized directly instead obtain
+        .. note:: This class should not be initialized directly. Instead obtain
            an instance via: ``reddit.subreddit('subreddit_name')``
 
         """
@@ -267,8 +300,8 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
         if display_name:
             self.display_name = display_name
         self._banned = self._contributor = self._filters = self._flair = None
-        self._mod = self._moderator = self._muted = self._quarantine = None
-        self._stream = self._stylesheet = self._wiki = None
+        self._mod = self._moderator = self._modmail = self._muted = None
+        self._quarantine = self._stream = self._stylesheet = self._wiki = None
         self._path = API_PATH['subreddit'].format(subreddit=self)
 
     def _info_path(self):
@@ -285,7 +318,15 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
             self._reddit.config.reddit_url, path))
 
     def rules(self):
-        """Return rules for the subreddit."""
+        """Return rules for the subreddit.
+
+        For example to show the rules of ``/r/redditdev`` try:
+
+        .. code:: python
+
+           reddit.subreddit('redditdev').rules()
+
+        """
         return self._reddit.get(API_PATH['rules'].format(subreddit=self))
 
     def search(self, query, sort='relevance', syntax='cloudsearch',
@@ -296,10 +337,14 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
         :param sort: Can be one of: relevance, hot, top, new,
             comments. (default: relevance).
         :param syntax: Can be one of: cloudsearch, lucene, plain
-            (default: cloudsearch).
+            (default: cloudsearch -- will be lucene in PRAW 5).
         :param time_filter: Can be one of: all, day, hour, month, week, year
             (default: all).
 
+        .. warning:: (Deprecation) The default search syntax is changing to
+           ``lucene`` in PRAW 5. For forward compatibility please explicitly
+           provide the search syntax.
+
         For more information on building a search query see:
             https://www.reddit.com/wiki/search
 
@@ -346,7 +391,7 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
             submission yielded during the call. A value of ``None`` will
             consider all submissions newer than ``start`` (default: None).
         :param extra_query: A cloudsearch query that will be combined via
-            ``(and timestamp:start..end EXTRA_QUERY)`` to futher filter
+            ``(and timestamp:start..end EXTRA_QUERY)`` to further filter
             results (default: None).
 
         Submissions are yielded newest first.
@@ -397,6 +442,7 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
         :param title: The title of the submission.
         :param selftext: The markdown formatted content for a ``text``
+            submission. Use an empty string, ``''``, to make a title-only
             submission.
         :param url: The URL for a ``link`` submission.
         :param resubmit: When False, an error will occur if the URL has already
@@ -416,7 +462,7 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
            reddit.subreddit('reddit_api_test').submit(url=url)
 
         """
-        if bool(selftext) == bool(url):
+        if (bool(selftext) or selftext == '') == bool(url):
             raise TypeError('Either `selftext` or `url` must be provided.')
 
         data = {'sr': str(self), 'resubmit': bool(resubmit),
@@ -464,7 +510,7 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 class SubredditFilters(object):
     """Provide functions to interact with the special Subreddit's filters.
 
-    Members of this class should be utilized via ``Subreddit.fiters``. For
+    Members of this class should be utilized via ``Subreddit.filters``. For
     example to add a filter run:
 
     .. code:: python
@@ -851,6 +897,13 @@ class SubredditModeration(object):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
+        To print all items in the edited queue try:
+
+        .. code:: python
+
+           for item in reddit.subreddit('mod').mod.edited(limit=None):
+               print(item)
+
         """
         self._handle_only(only, generator_kwargs)
         return ListingGenerator(
@@ -876,6 +929,15 @@ class SubredditModeration(object):
 
         See ``unread`` for unread moderator messages.
 
+        To print the last 5 moderator mail messages and their replies, try:
+
+        .. code:: python
+
+           for message in reddit.subreddit('mod').mod.inbox(limit=5):
+               print("From: {}, Body: {}".format(message.author, message.body))
+               for reply in message.replies:
+                   print("From: {}, Body: {}".format(reply.author, reply.body))
+
         """
         return ListingGenerator(
             self.subreddit._reddit, API_PATH['moderator_messages'].format(
@@ -889,6 +951,13 @@ class SubredditModeration(object):
         :param mod: If given, only return log entries for actions made by the
             passed in Redditor.
 
+        To print the moderator and subreddit of the last 5 modlog entries try:
+
+        .. code:: python
+
+           for log in reddit.subreddit('mod').mod.log(limit=5):
+               print("Mod: {}, Subreddit: {}".format(log.mod, log.subreddit))
+
         """
         params = {'mod': str(mod) if mod else mod, 'type': action}
         Subreddit._safely_add_arguments(generator_kwargs, 'params',
@@ -906,6 +975,13 @@ class SubredditModeration(object):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
+        To print all modqueue items try:
+
+        .. code:: python
+
+           for item in reddit.subreddit('mod').mod.modqueue(limit=None):
+               print(item)
+
         """
         self._handle_only(only, generator_kwargs)
         return ListingGenerator(
@@ -932,6 +1008,14 @@ class SubredditModeration(object):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
+        To print the user and mod report reasons in the report queue try:
+
+        .. code:: python
+
+           for item in reddit.subreddit('mod').mod.reports():
+               print("User Reports: {}".format(report.user_reports))
+               print("Mod Reports: {}".format(report.mod_reports))
+
         """
         self._handle_only(only, generator_kwargs)
         return ListingGenerator(
@@ -952,6 +1036,13 @@ class SubredditModeration(object):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
+        To print the items in the spam queue try:
+
+        .. code:: python
+
+           for item in reddit.subreddit('mod').mod.spam():
+               print(item)
+
         """
         self._handle_only(only, generator_kwargs)
         return ListingGenerator(
@@ -986,6 +1077,13 @@ class SubredditModeration(object):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
+        To print the items in the unmoderated queue try:
+
+        .. code:: python
+
+           for item in reddit.subreddit('mod').mod.unmoderated():
+               print(item)
+
         """
         return ListingGenerator(
             self.subreddit._reddit, API_PATH['about_unmoderated'].format(
@@ -999,6 +1097,13 @@ class SubredditModeration(object):
 
         See ``inbox`` for all messages.
 
+        To print the mail in the unread modmail queue try:
+
+        .. code:: python
+
+           for message in reddit.subreddit('mod').mod.unread():
+               print("From: {}, To: {}".format(message.author, message.dest))
+
         """
         return ListingGenerator(
             self.subreddit._reddit, API_PATH['moderator_unread'].format(
@@ -1065,7 +1170,15 @@ class SubredditModeration(object):
         Additional keyword arguments can be provided to handle new settings as
         Reddit introduces them.
 
-        Unspecified settings will maintain their current value.
+        Settings that are documented here and aren't explicitly set by you in a
+        call to :meth:`.SubredditModeration.update` should retain their current
+        value. If they do not please file a bug.
+
+        .. warning:: Undocumented settings, or settings that were very recently
+                     documented, may not retain their current value when
+                     updating. This often occurs when Reddit adds a new setting
+                     but forgets to add that setting to the API endpoint that
+                     is used to fetch the current settings.
 
         """
         current_settings = self.settings()
@@ -1084,7 +1197,7 @@ class SubredditModeration(object):
 
 
 class SubredditQuarantine(object):
-    """Provides submission and comment streams."""
+    """Provides subreddit quarantine related methods."""
 
     def __init__(self, subreddit):
         """Create a SubredditQuarantine instance.
@@ -1276,6 +1389,14 @@ class ModeratorRelationship(SubredditRelationship):
 
            moderators = reddit.subreddit('nameofsub').moderator()
 
+        For example, to list the moderators along with their permissions try:
+
+        .. code:: python
+
+           for moderator in reddit.subreddit('SUBREDDIT').moderator():
+               print('{}: {}'.format(moderator, moderator.mod_permissions))
+
+
         """
         params = {} if redditor is None else {'user': redditor}
         url = API_PATH['list_{}'.format(self.relationship)].format(
@@ -1295,6 +1416,13 @@ class ModeratorRelationship(SubredditRelationship):
         An invite will be sent unless the user making this call is an admin
         user.
 
+        For example, to invite ``'spez'`` with ``'posts'`` and ``'mail'``
+            permissions to ``'/r/test/``, try:
+
+        .. code:: python
+
+           reddit.subreddit('test').moderator.add('spez', ['posts', 'mail'])
+
         """
         other_settings = self._handle_permissions(permissions, other_settings)
         super(ModeratorRelationship, self).add(redditor, **other_settings)
@@ -1309,6 +1437,13 @@ class ModeratorRelationship(SubredditRelationship):
             empty list `[]` indicates no permissions, and when not provided
             `None`, indicates full permissions.
 
+        For example, to invite ``'spez'`` with ``'posts'`` and ``'mail'``
+            permissions to ``'/r/test/``, try:
+
+        .. code:: python
+
+           reddit.subreddit('test').moderator.invite('spez', ['posts', 'mail'])
+
         """
         data = self._handle_permissions(permissions, other_settings)
         data.update({'name': str(redditor), 'type': 'moderator_invite'})
@@ -1316,7 +1451,15 @@ class ModeratorRelationship(SubredditRelationship):
         self.subreddit._reddit.post(url, data=data)
 
     def leave(self):
-        """Abdicate the moderator position (use with care)."""
+        """Abdicate the moderator position (use with care).
+
+        Example:
+
+        .. code:: python
+
+           reddit.subreddit('subredditname').moderator.leave()
+
+        """
         self.subreddit._reddit.post(API_PATH['leavemoderator'],
                                     data={'id': self.subreddit.fullname})
 
@@ -1330,7 +1473,7 @@ class ModeratorRelationship(SubredditRelationship):
 
         .. code:: python
 
-           reddit.subreddit('subredditname').mod.remove_invite('spez')
+           reddit.subreddit('subredditname').moderator.remove_invite('spez')
 
         """
         data = {'name': str(redditor), 'type': 'moderator_invite'}
@@ -1389,6 +1532,171 @@ class ModeratorRelationship(SubredditRelationship):
         self.subreddit._reddit.post(url, data=data)
 
 
+class Modmail(object):
+    """Provides modmail functions for a subreddit."""
+
+    def __call__(self, id=None, mark_read=False):
+        """Return an individual conversation.
+
+        :param id: A reddit base36 conversation ID, e.g., ``2gmz``.
+        :param mark_read: If True, conversation is marked as read
+            (default: False).
+
+        Example:
+
+        .. code:: python
+
+           reddit.subreddit('redditdev').modmail('2gmz', mark_read=True)
+
+        """
+        # pylint: disable=invalid-name,redefined-builtin
+        return ModmailConversation(self.subreddit._reddit, id=id,
+                                   mark_read=mark_read)
+
+    def __init__(self, subreddit):
+        """Construct an instance of the Modmail object."""
+        self.subreddit = subreddit
+
+    def _build_subreddit_list(self, other_subreddits):
+        """Return a comma-separated list of subreddit display names."""
+        subreddits = [self.subreddit] + (other_subreddits or [])
+        return ','.join(str(subreddit) for subreddit in subreddits)
+
+    def bulk_read(self, other_subreddits=None, state=None):
+        """Mark conversations for subreddit(s) as read.
+
+        Due to server-side restrictions, 'all' is not a valid subreddit for
+        this method. Instead, use :meth:`~.Modmail.subreddits` to get a list of
+        subreddits using the new modmail.
+
+        :param other_subreddits: A list of `.Subreddit` instances for which to
+            mark conversations (default: None).
+        :param state: Can be one of: all, archived, highlighted, inprogress,
+            mod, new, notifications, (default: all).
+        :returns: A list of :class:`.ModmailConversation` instances that were
+            marked read.
+
+        For example, to mark all notifications for a subreddit as read:
+
+        .. code:: python
+
+           subreddit = reddit.subreddit('redditdev')
+           subreddit.modmail.bulk_read(state='notifications')
+
+        """
+        params = {'entity': self._build_subreddit_list(other_subreddits)}
+        if state:
+            params['state'] = state
+        response = self.subreddit._reddit.post(
+            API_PATH['modmail_bulk_read'], params=params)
+        return [self(conversation_id)
+                for conversation_id in response['conversation_ids']]
+
+    def conversations(self, after=None, limit=None, other_subreddits=None,
+                      sort=None, state=None):
+        """Generate :class:`.ModmailConversation` objects for subreddit(s).
+
+        :param after: A base36 modmail conversation id. When provided, the
+            listing begins after this conversation (default: None).
+        :param limit: The maximum number of conversations to fetch. If None,
+            the server-side default is 25 at the time of writing
+            (default: None).
+        :param other_subreddits: A list of `.Subreddit` instances for which to
+            fetch conversations (default: None).
+        :param sort: Can be one of: mod, recent, unread, user
+            (default: recent).
+        :param state: Can be one of: all, archived, highlighted, inprogress,
+            mod, new, notifications, (default: all).
+
+        Example:
+
+        .. code:: python
+
+            conversations = reddit.subreddit('all').conversations(state='mod')
+
+        """
+        params = {}
+        if self.subreddit != 'all':
+            params['entity'] = self._build_subreddit_list(other_subreddits)
+
+        for name, value in {'after': after, 'limit': limit, 'sort': sort,
+                            'state': state}.items():
+            if value:
+                params[name] = value
+
+        response = self.subreddit._reddit.get(
+            API_PATH['modmail_conversations'], params=params)
+        for conversation_id in response['conversationIds']:
+            data = {'conversation': response['conversations'][conversation_id],
+                    'messages': response['messages']}
+            yield ModmailConversation.parse(data, self.subreddit._reddit,
+                                            convert_objects=False)
+
+    def create(self, subject, body, recipient, author_hidden=False):
+        """Create a new modmail conversation.
+
+        :param subject: The message subject. Cannot be empty.
+        :param body: The message body. Cannot be empty.
+        :param recipient: The recipient; a username or an instance of
+            :class:`.Redditor`.
+        :param author_hidden: When True, author is hidden from non-moderators
+            (default: False).
+        :returns: A `.ModmailConversation` object for the newly created
+            conversation.
+
+        .. code:: python
+
+           subreddit = reddit.subreddit('redditdev')
+           redditor = reddit.redditor('bboe')
+           subreddit.modmail.create('Subject', 'Body', redditor)
+
+        """
+        data = {
+            'body': body,
+            'isAuthorHidden': author_hidden,
+            'srName': self.subreddit,
+            'subject': subject,
+            'to': recipient,
+        }
+        return self.subreddit._reddit.post(API_PATH['modmail_conversations'],
+                                           data=data)
+
+    def subreddits(self):
+        """Yield subreddits using the new modmail that the user moderates.
+
+        Example:
+
+        .. code:: python
+
+           subreddits = reddit.subreddit('all').modmail.subreddits()
+
+        """
+        response = self.subreddit._reddit.get(API_PATH['modmail_subreddits'])
+        for value in response['subreddits'].values():
+            subreddit = self.subreddit._reddit.subreddit(value['display_name'])
+            subreddit.last_updated = value['lastUpdated']
+            yield subreddit
+
+    def unread_count(self):
+        """Return unread conversation count by conversation state.
+
+        At time of writing, possible states are: archived, highlighted,
+        inprogress, mod, new, notifications.
+
+        :returns: A dict mapping conversation states to unread counts.
+
+        For example, to print the count of unread moderator discussions:
+
+        .. code:: python
+
+           subreddit = reddit.subreddit('redditdev')
+           unread_counts = subreddit.modmail.unread_count()
+           print(unread_counts['mod'])
+
+        """
+        return self.subreddit._reddit.get(API_PATH['modmail_unread_count'])
+
+
 class SubredditStream(object):
     """Provides submission and comment streams."""
 
@@ -1400,12 +1708,14 @@ class SubredditStream(object):
         """
         self.subreddit = subreddit
 
-    def comments(self):
+    def comments(self, **stream_options):
         """Yield new comments as they become available.
 
         Comments are yielded oldest first. Up to 100 historical comments will
         initially be returned.
 
+        Keyword arguments are passed to :meth:`.stream_generator`.
+
         For example, to retrieve all new comments made to the ``iama``
         subreddit, try:
 
@@ -1415,14 +1725,16 @@ class SubredditStream(object):
                print(comment)
 
         """
-        return stream_generator(self.subreddit.comments)
+        return stream_generator(self.subreddit.comments, **stream_options)
 
-    def submissions(self):
+    def submissions(self, **stream_options):
         """Yield new submissions as they become available.
 
         Submissions are yielded oldest first. Up to 100 historical submissions
         will initially be returned.
 
+        Keyword arguments are passed to :meth:`.stream_generator`.
+
         For example to retrieve all new submissions made to all of Reddit, try:
 
         .. code:: python
@@ -1431,7 +1743,7 @@ class SubredditStream(object):
                print(submission)
 
         """
-        return stream_generator(self.subreddit.new)
+        return stream_generator(self.subreddit.new, **stream_options)
 
 
 class SubredditStylesheet(object):
@@ -1440,7 +1752,15 @@ class SubredditStylesheet(object):
     JPEG_HEADER = b'\xff\xd8\xff'
 
     def __call__(self):
-        """Return the subreddit's stylesheet."""
+        """Return the subreddit's stylesheet.
+
+        To be used as:
+
+        .. code:: python
+
+           stylesheet = reddit.subreddit('SUBREDDIT').stylesheet()
+
+        """
         url = API_PATH['about_stylesheet'].format(subreddit=self.subreddit)
         return self.subreddit._reddit.get(url)
 
@@ -1449,6 +1769,12 @@ class SubredditStylesheet(object):
 
         :param subreddit: The subreddit associated with the stylesheet.
 
+        An instance of this class is provided as:
+
+        .. code:: python
+
+           reddit.subreddit('SUBREDDIT').stylesheet
+
         """
         self.subreddit = subreddit
 
@@ -1458,14 +1784,25 @@ class SubredditStylesheet(object):
             image.seek(0)
             data['img_type'] = 'jpg' if header == self.JPEG_HEADER else 'png'
             url = API_PATH['upload_image'].format(subreddit=self.subreddit)
-            return self.subreddit._reddit.post(
-                url, data=data, files={'file': image})
+            response = self.subreddit._reddit.post(url, data=data,
+                                                   files={'file': image})
+            if response['errors']:
+                assert response['errors'] == ['IMAGE_ERROR'], \
+                                             'Please file a bug with PRAW'
+                raise APIException(response['errors'][0], '', None)
+            return response
 
     def delete_header(self):
         """Remove the current subreddit header image.
 
         Succeeds even if there is no header image.
 
+        Example:
+
+        .. code:: python
+
+           reddit.subreddit('SUBREDDIT').stylesheet.delete_header()
+
         """
         url = API_PATH['delete_sr_header'].format(subreddit=self.subreddit)
         self.subreddit._reddit.post(url)
@@ -1475,15 +1812,58 @@ class SubredditStylesheet(object):
 
         Succeeds even if the named image does not exist.
 
+        Example:
+
+        .. code:: python
+
+           reddit.subreddit('SUBREDDIT').stylesheet.delete_image('smile')
+
         """
         url = API_PATH['delete_sr_image'].format(subreddit=self.subreddit)
         self.subreddit._reddit.post(url, data={'img_name': name})
 
+    def delete_mobile_header(self):
+        """Remove the current subreddit mobile header.
+
+        Succeeds even if there is no mobile header.
+
+        Example:
+
+        .. code:: python
+
+           reddit.subreddit('SUBREDDIT').stylesheet.delete_mobile_header()
+
+        """
+        url = API_PATH['delete_sr_header'].format(subreddit=self.subreddit)
+        self.subreddit._reddit.post(url)
+
+    def delete_mobile_icon(self):
+        """Remove the current subreddit mobile icon.
+
+        Succeeds even if there is no mobile icon.
+
+        Example:
+
+        .. code:: python
+
+           reddit.subreddit('SUBREDDIT').stylesheet.delete_mobile_icon()
+
+        """
+        url = API_PATH['delete_sr_icon'].format(subreddit=self.subreddit)
+        self.subreddit._reddit.post(url)
+
     def update(self, stylesheet, reason=None):
         """Update the subreddit's stylesheet.
 
         :param stylesheet: The CSS for the new stylesheet.
 
+        Example:
+
+        .. code:: python
+
+           reddit.subreddit('SUBREDDIT').stylesheet.update(
+               'p { color: green; }', 'color text green')
+
         """
         data = {'op': 'save', 'reason': reason,
                 'stylesheet_contents': stylesheet}
@@ -1499,6 +1879,19 @@ class SubredditStylesheet(object):
         :returns: A dictionary containing a link to the uploaded image under
             the key ``img_src``.
 
+        Raises ``prawcore.TooLarge`` if the overall request body is too large.
+
+        Raises :class:`.APIException` if there are other issues with the
+        uploaded image. Unfortunately the exception info might not be very
+        specific, so try through the website with the same image to see what
+        the problem actually might be.
+
+        Example:
+
+        .. code:: python
+
+           reddit.subreddit('SUBREDDIT').stylesheet.upload('smile', 'img.png')
+
         """
         return self._upload_image(image_path,
                                   {'name': name, 'upload_type': 'img'})
@@ -1510,9 +1903,70 @@ class SubredditStylesheet(object):
         :returns: A dictionary containing a link to the uploaded image under
             the key ``img_src``.
 
+        Raises ``prawcore.TooLarge`` if the overall request body is too large.
+
+        Raises :class:`.APIException` if there are other issues with the
+        uploaded image. Unfortunately the exception info might not be very
+        specific, so try through the website with the same image to see what
+        the problem actually might be.
+
+        Example:
+
+        .. code:: python
+
+           reddit.subreddit('SUBREDDIT').stylesheet.upload_header('header.png')
+
         """
         return self._upload_image(image_path, {'upload_type': 'header'})
 
+    def upload_mobile_header(self, image_path):
+        """Upload an image to be used as the Subreddit's mobile header.
+
+        :param image_path: A path to a jpeg or png image.
+        :returns: A dictionary containing a link to the uploaded image under
+            the key ``img_src``.
+
+        Raises ``prawcore.TooLarge`` if the overall request body is too large.
+
+        Raises :class:`.APIException` if there are other issues with the
+        uploaded image. Unfortunately the exception info might not be very
+        specific, so try through the website with the same image to see what
+        the problem actually might be.
+
+        For example:
+
+        .. code:: python
+
+           reddit.subreddit('SUBREDDIT').stylesheet.upload_mobile_header(
+               'header.png')
+
+        """
+        return self._upload_image(image_path, {'upload_type': 'banner'})
+
+    def upload_mobile_icon(self, image_path):
+        """Upload an image to be used as the Subreddit's mobile icon.
+
+        :param image_path: A path to a jpeg or png image.
+        :returns: A dictionary containing a link to the uploaded image under
+            the key ``img_src``.
+
+        Raises ``prawcore.TooLarge`` if the overall request body is too large.
+
+        Raises :class:`.APIException` if there are other issues with the
+        uploaded image. Unfortunately the exception info might not be very
+        specific, so try through the website with the same image to see what
+        the problem actually might be.
+
+        For example:
+
+        .. code:: python
+
+           reddit.subreddit('SUBREDDIT').stylesheet.upload_mobile_icon(
+               'icon.png')
+
+        """
+        return self._upload_image(image_path, {'upload_type': 'icon'})
+
 
 class SubredditWiki(object):
     """Provides a set of moderation functions to a Subreddit."""
@@ -1561,11 +2015,19 @@ class SubredditWiki(object):
     def create(self, name, content, reason=None, **other_settings):
         """Create a new wiki page.
 
-        :param name: The name of the new WikiPage. This name will be normalied.
+        :param name: The name of the new WikiPage. This name will be
+            normalized.
         :param content: The content of the new WikiPage.
         :param reason: (Optional) The reason for the creation.
         :param other_settings: Additional keyword arguments to pass.
 
+        To create the wiki page ``'praw_test'`` in ``'/r/test'`` try:
+
+        .. code:: python
+
+           reddit.subreddit('test').wiki.create(
+               'praw_test', 'wiki body text', reason='PRAW Test Creation')
+
         """
         name = name.replace(' ', '_').lower()
         new = WikiPage(self.subreddit._reddit, self.subreddit, name)
@@ -1578,6 +2040,13 @@ class SubredditWiki(object):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
+        To view the wiki revisions for ``'praw_test'`` in ``'/r/test'`` try:
+
+        .. code:: python
+
+           for item in reddit.subreddit('test').wiki['praw_test'].revisions():
+               print(item)
+
         """
         url = API_PATH['wiki_revisions'].format(subreddit=self.subreddit)
         return WikiPage._revision_generator(
