@@ -12,15 +12,16 @@ class WikiPage(RedditBase):
     def _revision_generator(subreddit, url, generator_kwargs):
         for revision in ListingGenerator(subreddit._reddit, url,
                                          **generator_kwargs):
-            revision['author'] = Redditor(subreddit._reddit,
-                                          _data=revision['author']['data'])
+            if revision['author'] is not None:
+                revision['author'] = Redditor(subreddit._reddit,
+                                              _data=revision['author']['data'])
             revision['page'] = WikiPage(subreddit._reddit, subreddit,
                                         revision['page'], revision['id'])
             yield revision
 
     @property
     def mod(self):
-        """An instance of :class:`.WikiPageModeration`."""
+        """Provide an instance of :class:`.WikiPageModeration`."""
         if self._mod is None:
             self._mod = WikiPageModeration(self)
         return self._mod
@@ -59,8 +60,9 @@ class WikiPage(RedditBase):
     def _fetch(self):
         params = {'v': self._revision} if self._revision else None
         data = self._reddit.get(self._info_path(), params=params)['data']
-        data['revision_by'] = Redditor(self._reddit,
-                                       _data=data['revision_by']['data'])
+        if data['revision_by'] is not None:
+            data['revision_by'] = Redditor(self._reddit,
+                                           _data=data['revision_by']['data'])
         self.__dict__.update(data)
         self._fetched = True
 
@@ -87,6 +89,13 @@ class WikiPage(RedditBase):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
+        To view the wiki revisions for ``'praw_test'`` in ``'/r/test'`` try:
+
+        .. code:: python
+
+           for item in reddit.subreddit('test').wiki['praw_test'].revisions():
+               print(item)
+
         """
         url = API_PATH['wiki_page_revisions'].format(subreddit=self.subreddit,
                                                      page=self.name)
@@ -110,6 +119,12 @@ class WikiPageModeration(object):
         :param redditor: A redditor name (e.g., ``'spez'``) or
             :class:`~.Redditor` instance.
 
+        To add ``'spez'`` as an editor on the wikipage ``'praw_test'`` try:
+
+        .. code:: python
+
+           reddit.subreddit('test').wiki['praw_test'].mod.add('spez')
+
         """
         data = {'page': self.wikipage.name, 'username': str(redditor)}
         url = API_PATH['wiki_page_editor'].format(
@@ -122,6 +137,12 @@ class WikiPageModeration(object):
         :param redditor: A redditor name (e.g., ``'spez'``) or
             :class:`~.Redditor` instance.
 
+        To remove ``'spez'`` as an editor on the wikipage ``'praw_test'`` try:
+
+        .. code:: python
+
+           reddit.subreddit('test').wiki['praw_test'].mod.remove('spez')
+
         """
         data = {'page': self.wikipage.name, 'username': str(redditor)}
         url = API_PATH['wiki_page_editor'].format(
@@ -144,6 +165,14 @@ class WikiPageModeration(object):
         :param other_settings: Additional keyword arguments to pass.
         :returns: The updated WikiPage settings.
 
+        To set the wikipage ``'praw_test'`` in ``'/r/test'`` to mod only and
+          disable it from showing in the page list, try:
+
+        .. code:: python
+
+           reddit.subreddit('test').wiki['praw_test'].mod.update(listed=False,
+                                                                 permlevel=2)
+
         """
         other_settings.update({'listed': listed, 'permlevel': permlevel})
         url = API_PATH['wiki_page_settings'].format(
